==> qtmclock_src-0.1.0.tar.gz: qtmclock_src-0.1.0/parts_generator/parts_generator_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>PartsGeneratorWindow</name>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="56"/>
        <source>About parts_generator</source>
        <translation>Parts Generator について</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="60"/>
        <source>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Theme making sub tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成補助ツール&lt;/p&gt;&lt;p&gt;バグ報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>PartsGeneratorWindowForm</name>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="18"/>
        <source>Parts Generator</source>
        <translation>Parts Generator</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="35"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="41"/>
        <source>week of the day</source>
        <translation>曜日</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="48"/>
        <source>calendar separator</source>
        <translation>月日</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="55"/>
        <source>calendar number</source>
        <translation>数字 (カレンダー)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="62"/>
        <source>clock number</source>
        <translation>数字 (時計)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="89"/>
        <source>Config</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="139"/>
        <source>Font size</source>
        <translation>フォントサイズ</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="95"/>
        <source>Font color</source>
        <translation>フォントの色</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="112"/>
        <source>Outline color</source>
        <translation>枠の色</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="156"/>
        <source>Input text</source>
        <translation>タグ文字の入力</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="149"/>
        <source>Input</source>
        <translation>入力</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="166"/>
        <source>Outline size</source>
        <translation>枠幅</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="199"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="224"/>
        <source>dummy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="241"/>
        <source>&amp;File</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="272"/>
        <source>&amp;New</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="277"/>
        <source>&amp;Save</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="282"/>
        <source>&amp;Open</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="287"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="292"/>
        <source>&amp;Release</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="297"/>
        <source>&amp;Quit</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="300"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="253"/>
        <source>&amp;Help</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="305"/>
        <source>&amp;About</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
</context>
</TS>

==> qtmclock_src-0.1.1.tar.gz: qtmclock_src-0.1.1/parts_generator/parts_generator_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>PartsGeneratorWindow</name>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="124"/>
        <source>About parts_generator</source>
        <translation>Parts Generator について</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="128"/>
        <source>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Theme making sub tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成補助ツール&lt;/p&gt;&lt;p&gt;バグ報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="80"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="81"/>
        <source>Create a new config file.</source>
        <translation>設定ファイルの新規作成.</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="84"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="85"/>
        <source>Open an exist config file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="88"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="89"/>
        <source>Save the config file to disk.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindow.cpp" line="98"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
</context>
<context>
    <name>PartsGeneratorWindowForm</name>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="18"/>
        <source>Parts Generator</source>
        <translation>Parts Generator</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="35"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="41"/>
        <source>week of the day</source>
        <translation>曜日</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="48"/>
        <source>calendar separator</source>
        <translation>月日</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="55"/>
        <source>calendar number</source>
        <translation>数字 (カレンダー)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="62"/>
        <source>clock number</source>
        <translation>数字 (時計)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="89"/>
        <source>Config</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="139"/>
        <source>Font size</source>
        <translation>フォントサイズ</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="95"/>
        <source>Font color</source>
        <translation>フォントの色</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="112"/>
        <source>Outline color</source>
        <translation>枠の色</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="156"/>
        <source>Input text</source>
        <translation>タグ文字の入力</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="149"/>
        <source>Input</source>
        <translation>入力</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="166"/>
        <source>Outline size</source>
        <translation>枠の幅</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="216"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="241"/>
        <source>dummy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="258"/>
        <source>&amp;File</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="313"/>
        <source>&amp;New</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="318"/>
        <source>&amp;Save</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="323"/>
        <source>&amp;Open</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="328"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="333"/>
        <source>&amp;Release</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="338"/>
        <source>&amp;Quit</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="341"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="270"/>
        <source>&amp;Help</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="346"/>
        <source>&amp;About</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="302"/>
        <source>toolBar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="PartsGeneratorWindowForm.ui" line="192"/>
        <source>Background color</source>
        <translation>背景色</translation>
    </message>
</context>
</TS>
